# @generated

# This file was generated by running `python -m dagster.grpc.compile`
# Do not edit this file directly, and do not attempt to recompile it using
# grpc_tools.protoc directly, as several changes must be made to the raw output

# pylint: disable=protected-access,no-name-in-module

# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name="api.proto",
    package="api",
    syntax="proto3",
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n\tapi.proto\x12\x03\x61pi"\x07\n\x05\x45mpty"\x1b\n\x0bPingRequest\x12\x0c\n\x04\x65\x63ho\x18\x01 \x01(\t"\x19\n\tPingReply\x12\x0c\n\x04\x65\x63ho\x18\x01 \x01(\t"=\n\x14StreamingPingRequest\x12\x17\n\x0fsequence_length\x18\x01 \x01(\x05\x12\x0c\n\x04\x65\x63ho\x18\x02 \x01(\t";\n\x12StreamingPingEvent\x12\x17\n\x0fsequence_number\x18\x01 \x01(\x05\x12\x0c\n\x04\x65\x63ho\x18\x02 \x01(\t"%\n\x10GetServerIdReply\x12\x11\n\tserver_id\x18\x01 \x01(\t"O\n\x1c\x45xecutionPlanSnapshotRequest\x12/\n\'serialized_execution_plan_snapshot_args\x18\x01 \x01(\t"H\n\x1a\x45xecutionPlanSnapshotReply\x12*\n"serialized_execution_plan_snapshot\x18\x01 \x01(\t"H\n\x1d\x45xternalPartitionNamesRequest\x12\'\n\x1fserialized_partition_names_args\x18\x01 \x01(\t"p\n\x1b\x45xternalPartitionNamesReply\x12Q\nIserialized_external_partition_names_or_external_partition_execution_error\x18\x01 \x01(\t"C\n\x1e\x45xternalPartitionConfigRequest\x12!\n\x19serialized_partition_args\x18\x01 \x01(\t"r\n\x1c\x45xternalPartitionConfigReply\x12R\nJserialized_external_partition_config_or_external_partition_execution_error\x18\x01 \x01(\t"A\n\x1c\x45xternalPartitionTagsRequest\x12!\n\x19serialized_partition_args\x18\x01 \x01(\t"n\n\x1a\x45xternalPartitionTagsReply\x12P\nHserialized_external_partition_tags_or_external_partition_execution_error\x18\x01 \x01(\t"c\n*ExternalPartitionSetExecutionParamsRequest\x12\x35\n-serialized_partition_set_execution_param_args\x18\x01 \x01(\t"\x90\x01\n(ExternalPartitionSetExecutionParamsReply\x12\x64\n\\serialized_external_partition_set_execution_param_data_or_external_partition_execution_error\x18\x01 \x01(\t"\x19\n\x17ListRepositoriesRequest"O\n\x15ListRepositoriesReply\x12\x36\n.serialized_list_repositories_response_or_error\x18\x01 \x01(\t"Y\n%ExternalPipelineSubsetSnapshotRequest\x12\x30\n(serialized_pipeline_subset_snapshot_args\x18\x01 \x01(\t"Y\n#ExternalPipelineSubsetSnapshotReply\x12\x32\n*serialized_external_pipeline_subset_result\x18\x01 \x01(\t"H\n\x19\x45xternalRepositoryRequest\x12+\n#serialized_repository_python_origin\x18\x01 \x01(\t"F\n\x17\x45xternalRepositoryReply\x12+\n#serialized_external_repository_data\x18\x01 \x01(\t"i\n StreamingExternalRepositoryEvent\x12\x17\n\x0fsequence_number\x18\x01 \x01(\x05\x12,\n$serialized_external_repository_chunk\x18\x02 \x01(\t"W\n ExternalScheduleExecutionRequest\x12\x33\n+serialized_external_schedule_execution_args\x18\x01 \x01(\t"z\n\x1e\x45xternalScheduleExecutionReply\x12X\nPserialized_external_schedule_execution_data_or_external_schedule_execution_error\x18\x01 \x01(\t"S\n\x1e\x45xternalSensorExecutionRequest\x12\x31\n)serialized_external_sensor_execution_args\x18\x01 \x01(\t"t\n\x1c\x45xternalSensorExecutionReply\x12T\nLserialized_external_sensor_execution_data_or_external_sensor_execution_error\x18\x01 \x01(\t"@\n\x13ShutdownServerReply\x12)\n!serialized_shutdown_server_result\x18\x01 \x01(\t"E\n\x16\x43\x61ncelExecutionRequest\x12+\n#serialized_cancel_execution_request\x18\x01 \x01(\t"B\n\x14\x43\x61ncelExecutionReply\x12*\n"serialized_cancel_execution_result\x18\x01 \x01(\t"L\n\x19\x43\x61nCancelExecutionRequest\x12/\n\'serialized_can_cancel_execution_request\x18\x01 \x01(\t"I\n\x17\x43\x61nCancelExecutionReply\x12.\n&serialized_can_cancel_execution_result\x18\x01 \x01(\t"6\n\x0fStartRunRequest\x12#\n\x1bserialized_execute_run_args\x18\x01 \x01(\t"4\n\rStartRunReply\x12#\n\x1bserialized_start_run_result\x18\x01 \x01(\t"8\n\x14GetCurrentImageReply\x12 \n\x18serialized_current_image\x18\x01 \x01(\t2\xa0\r\n\nDagsterApi\x12*\n\x04Ping\x12\x10.api.PingRequest\x1a\x0e.api.PingReply"\x00\x12/\n\tHeartbeat\x12\x10.api.PingRequest\x1a\x0e.api.PingReply"\x00\x12G\n\rStreamingPing\x12\x19.api.StreamingPingRequest\x1a\x17.api.StreamingPingEvent"\x00\x30\x01\x12\x32\n\x0bGetServerId\x12\n.api.Empty\x1a\x15.api.GetServerIdReply"\x00\x12]\n\x15\x45xecutionPlanSnapshot\x12!.api.ExecutionPlanSnapshotRequest\x1a\x1f.api.ExecutionPlanSnapshotReply"\x00\x12N\n\x10ListRepositories\x12\x1c.api.ListRepositoriesRequest\x1a\x1a.api.ListRepositoriesReply"\x00\x12`\n\x16\x45xternalPartitionNames\x12".api.ExternalPartitionNamesRequest\x1a .api.ExternalPartitionNamesReply"\x00\x12\x63\n\x17\x45xternalPartitionConfig\x12#.api.ExternalPartitionConfigRequest\x1a!.api.ExternalPartitionConfigReply"\x00\x12]\n\x15\x45xternalPartitionTags\x12!.api.ExternalPartitionTagsRequest\x1a\x1f.api.ExternalPartitionTagsReply"\x00\x12\x87\x01\n#ExternalPartitionSetExecutionParams\x12/.api.ExternalPartitionSetExecutionParamsRequest\x1a-.api.ExternalPartitionSetExecutionParamsReply"\x00\x12x\n\x1e\x45xternalPipelineSubsetSnapshot\x12*.api.ExternalPipelineSubsetSnapshotRequest\x1a(.api.ExternalPipelineSubsetSnapshotReply"\x00\x12T\n\x12\x45xternalRepository\x12\x1e.api.ExternalRepositoryRequest\x1a\x1c.api.ExternalRepositoryReply"\x00\x12h\n\x1bStreamingExternalRepository\x12\x1e.api.ExternalRepositoryRequest\x1a%.api.StreamingExternalRepositoryEvent"\x00\x30\x01\x12i\n\x19\x45xternalScheduleExecution\x12%.api.ExternalScheduleExecutionRequest\x1a#.api.ExternalScheduleExecutionReply"\x00\x12\x63\n\x17\x45xternalSensorExecution\x12#.api.ExternalSensorExecutionRequest\x1a!.api.ExternalSensorExecutionReply"\x00\x12\x38\n\x0eShutdownServer\x12\n.api.Empty\x1a\x18.api.ShutdownServerReply"\x00\x12K\n\x0f\x43\x61ncelExecution\x12\x1b.api.CancelExecutionRequest\x1a\x19.api.CancelExecutionReply"\x00\x12T\n\x12\x43\x61nCancelExecution\x12\x1e.api.CanCancelExecutionRequest\x1a\x1c.api.CanCancelExecutionReply"\x00\x12\x36\n\x08StartRun\x12\x14.api.StartRunRequest\x1a\x12.api.StartRunReply"\x00\x12:\n\x0fGetCurrentImage\x12\n.api.Empty\x1a\x19.api.GetCurrentImageReply"\x00\x62\x06proto3',
)


_EMPTY = _descriptor.Descriptor(
    name="Empty",
    full_name="api.Empty",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=18,
    serialized_end=25,
)


_PINGREQUEST = _descriptor.Descriptor(
    name="PingRequest",
    full_name="api.PingRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="echo",
            full_name="api.PingRequest.echo",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=27,
    serialized_end=54,
)


_PINGREPLY = _descriptor.Descriptor(
    name="PingReply",
    full_name="api.PingReply",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="echo",
            full_name="api.PingReply.echo",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=56,
    serialized_end=81,
)


_STREAMINGPINGREQUEST = _descriptor.Descriptor(
    name="StreamingPingRequest",
    full_name="api.StreamingPingRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="sequence_length",
            full_name="api.StreamingPingRequest.sequence_length",
            index=0,
            number=1,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="echo",
            full_name="api.StreamingPingRequest.echo",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=83,
    serialized_end=144,
)


_STREAMINGPINGEVENT = _descriptor.Descriptor(
    name="StreamingPingEvent",
    full_name="api.StreamingPingEvent",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="sequence_number",
            full_name="api.StreamingPingEvent.sequence_number",
            index=0,
            number=1,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="echo",
            full_name="api.StreamingPingEvent.echo",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=146,
    serialized_end=205,
)


_GETSERVERIDREPLY = _descriptor.Descriptor(
    name="GetServerIdReply",
    full_name="api.GetServerIdReply",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="server_id",
            full_name="api.GetServerIdReply.server_id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=207,
    serialized_end=244,
)


_EXECUTIONPLANSNAPSHOTREQUEST = _descriptor.Descriptor(
    name="ExecutionPlanSnapshotRequest",
    full_name="api.ExecutionPlanSnapshotRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_execution_plan_snapshot_args",
            full_name="api.ExecutionPlanSnapshotRequest.serialized_execution_plan_snapshot_args",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=246,
    serialized_end=325,
)


_EXECUTIONPLANSNAPSHOTREPLY = _descriptor.Descriptor(
    name="ExecutionPlanSnapshotReply",
    full_name="api.ExecutionPlanSnapshotReply",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_execution_plan_snapshot",
            full_name="api.ExecutionPlanSnapshotReply.serialized_execution_plan_snapshot",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=327,
    serialized_end=399,
)


_EXTERNALPARTITIONNAMESREQUEST = _descriptor.Descriptor(
    name="ExternalPartitionNamesRequest",
    full_name="api.ExternalPartitionNamesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_partition_names_args",
            full_name="api.ExternalPartitionNamesRequest.serialized_partition_names_args",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=401,
    serialized_end=473,
)


_EXTERNALPARTITIONNAMESREPLY = _descriptor.Descriptor(
    name="ExternalPartitionNamesReply",
    full_name="api.ExternalPartitionNamesReply",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_external_partition_names_or_external_partition_execution_error",
            full_name="api.ExternalPartitionNamesReply.serialized_external_partition_names_or_external_partition_execution_error",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=475,
    serialized_end=587,
)


_EXTERNALPARTITIONCONFIGREQUEST = _descriptor.Descriptor(
    name="ExternalPartitionConfigRequest",
    full_name="api.ExternalPartitionConfigRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_partition_args",
            full_name="api.ExternalPartitionConfigRequest.serialized_partition_args",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=589,
    serialized_end=656,
)


_EXTERNALPARTITIONCONFIGREPLY = _descriptor.Descriptor(
    name="ExternalPartitionConfigReply",
    full_name="api.ExternalPartitionConfigReply",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_external_partition_config_or_external_partition_execution_error",
            full_name="api.ExternalPartitionConfigReply.serialized_external_partition_config_or_external_partition_execution_error",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=658,
    serialized_end=772,
)


_EXTERNALPARTITIONTAGSREQUEST = _descriptor.Descriptor(
    name="ExternalPartitionTagsRequest",
    full_name="api.ExternalPartitionTagsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_partition_args",
            full_name="api.ExternalPartitionTagsRequest.serialized_partition_args",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=774,
    serialized_end=839,
)


_EXTERNALPARTITIONTAGSREPLY = _descriptor.Descriptor(
    name="ExternalPartitionTagsReply",
    full_name="api.ExternalPartitionTagsReply",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_external_partition_tags_or_external_partition_execution_error",
            full_name="api.ExternalPartitionTagsReply.serialized_external_partition_tags_or_external_partition_execution_error",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=841,
    serialized_end=951,
)


_EXTERNALPARTITIONSETEXECUTIONPARAMSREQUEST = _descriptor.Descriptor(
    name="ExternalPartitionSetExecutionParamsRequest",
    full_name="api.ExternalPartitionSetExecutionParamsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_partition_set_execution_param_args",
            full_name="api.ExternalPartitionSetExecutionParamsRequest.serialized_partition_set_execution_param_args",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=953,
    serialized_end=1052,
)


_EXTERNALPARTITIONSETEXECUTIONPARAMSREPLY = _descriptor.Descriptor(
    name="ExternalPartitionSetExecutionParamsReply",
    full_name="api.ExternalPartitionSetExecutionParamsReply",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_external_partition_set_execution_param_data_or_external_partition_execution_error",
            full_name="api.ExternalPartitionSetExecutionParamsReply.serialized_external_partition_set_execution_param_data_or_external_partition_execution_error",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1055,
    serialized_end=1199,
)


_LISTREPOSITORIESREQUEST = _descriptor.Descriptor(
    name="ListRepositoriesRequest",
    full_name="api.ListRepositoriesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1201,
    serialized_end=1226,
)


_LISTREPOSITORIESREPLY = _descriptor.Descriptor(
    name="ListRepositoriesReply",
    full_name="api.ListRepositoriesReply",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_list_repositories_response_or_error",
            full_name="api.ListRepositoriesReply.serialized_list_repositories_response_or_error",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1228,
    serialized_end=1307,
)


_EXTERNALPIPELINESUBSETSNAPSHOTREQUEST = _descriptor.Descriptor(
    name="ExternalPipelineSubsetSnapshotRequest",
    full_name="api.ExternalPipelineSubsetSnapshotRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_pipeline_subset_snapshot_args",
            full_name="api.ExternalPipelineSubsetSnapshotRequest.serialized_pipeline_subset_snapshot_args",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1309,
    serialized_end=1398,
)


_EXTERNALPIPELINESUBSETSNAPSHOTREPLY = _descriptor.Descriptor(
    name="ExternalPipelineSubsetSnapshotReply",
    full_name="api.ExternalPipelineSubsetSnapshotReply",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_external_pipeline_subset_result",
            full_name="api.ExternalPipelineSubsetSnapshotReply.serialized_external_pipeline_subset_result",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1400,
    serialized_end=1489,
)


_EXTERNALREPOSITORYREQUEST = _descriptor.Descriptor(
    name="ExternalRepositoryRequest",
    full_name="api.ExternalRepositoryRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_repository_python_origin",
            full_name="api.ExternalRepositoryRequest.serialized_repository_python_origin",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1491,
    serialized_end=1563,
)


_EXTERNALREPOSITORYREPLY = _descriptor.Descriptor(
    name="ExternalRepositoryReply",
    full_name="api.ExternalRepositoryReply",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_external_repository_data",
            full_name="api.ExternalRepositoryReply.serialized_external_repository_data",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1565,
    serialized_end=1635,
)


_STREAMINGEXTERNALREPOSITORYEVENT = _descriptor.Descriptor(
    name="StreamingExternalRepositoryEvent",
    full_name="api.StreamingExternalRepositoryEvent",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="sequence_number",
            full_name="api.StreamingExternalRepositoryEvent.sequence_number",
            index=0,
            number=1,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="serialized_external_repository_chunk",
            full_name="api.StreamingExternalRepositoryEvent.serialized_external_repository_chunk",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1637,
    serialized_end=1742,
)


_EXTERNALSCHEDULEEXECUTIONREQUEST = _descriptor.Descriptor(
    name="ExternalScheduleExecutionRequest",
    full_name="api.ExternalScheduleExecutionRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_external_schedule_execution_args",
            full_name="api.ExternalScheduleExecutionRequest.serialized_external_schedule_execution_args",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1744,
    serialized_end=1831,
)


_EXTERNALSCHEDULEEXECUTIONREPLY = _descriptor.Descriptor(
    name="ExternalScheduleExecutionReply",
    full_name="api.ExternalScheduleExecutionReply",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_external_schedule_execution_data_or_external_schedule_execution_error",
            full_name="api.ExternalScheduleExecutionReply.serialized_external_schedule_execution_data_or_external_schedule_execution_error",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1833,
    serialized_end=1955,
)


_EXTERNALSENSOREXECUTIONREQUEST = _descriptor.Descriptor(
    name="ExternalSensorExecutionRequest",
    full_name="api.ExternalSensorExecutionRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_external_sensor_execution_args",
            full_name="api.ExternalSensorExecutionRequest.serialized_external_sensor_execution_args",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1957,
    serialized_end=2040,
)


_EXTERNALSENSOREXECUTIONREPLY = _descriptor.Descriptor(
    name="ExternalSensorExecutionReply",
    full_name="api.ExternalSensorExecutionReply",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_external_sensor_execution_data_or_external_sensor_execution_error",
            full_name="api.ExternalSensorExecutionReply.serialized_external_sensor_execution_data_or_external_sensor_execution_error",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2042,
    serialized_end=2158,
)


_SHUTDOWNSERVERREPLY = _descriptor.Descriptor(
    name="ShutdownServerReply",
    full_name="api.ShutdownServerReply",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_shutdown_server_result",
            full_name="api.ShutdownServerReply.serialized_shutdown_server_result",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2160,
    serialized_end=2224,
)


_CANCELEXECUTIONREQUEST = _descriptor.Descriptor(
    name="CancelExecutionRequest",
    full_name="api.CancelExecutionRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_cancel_execution_request",
            full_name="api.CancelExecutionRequest.serialized_cancel_execution_request",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2226,
    serialized_end=2295,
)


_CANCELEXECUTIONREPLY = _descriptor.Descriptor(
    name="CancelExecutionReply",
    full_name="api.CancelExecutionReply",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_cancel_execution_result",
            full_name="api.CancelExecutionReply.serialized_cancel_execution_result",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2297,
    serialized_end=2363,
)


_CANCANCELEXECUTIONREQUEST = _descriptor.Descriptor(
    name="CanCancelExecutionRequest",
    full_name="api.CanCancelExecutionRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_can_cancel_execution_request",
            full_name="api.CanCancelExecutionRequest.serialized_can_cancel_execution_request",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2365,
    serialized_end=2441,
)


_CANCANCELEXECUTIONREPLY = _descriptor.Descriptor(
    name="CanCancelExecutionReply",
    full_name="api.CanCancelExecutionReply",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_can_cancel_execution_result",
            full_name="api.CanCancelExecutionReply.serialized_can_cancel_execution_result",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2443,
    serialized_end=2516,
)


_STARTRUNREQUEST = _descriptor.Descriptor(
    name="StartRunRequest",
    full_name="api.StartRunRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_execute_run_args",
            full_name="api.StartRunRequest.serialized_execute_run_args",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2518,
    serialized_end=2572,
)


_STARTRUNREPLY = _descriptor.Descriptor(
    name="StartRunReply",
    full_name="api.StartRunReply",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_start_run_result",
            full_name="api.StartRunReply.serialized_start_run_result",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2574,
    serialized_end=2626,
)


_GETCURRENTIMAGEREPLY = _descriptor.Descriptor(
    name="GetCurrentImageReply",
    full_name="api.GetCurrentImageReply",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="serialized_current_image",
            full_name="api.GetCurrentImageReply.serialized_current_image",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2628,
    serialized_end=2684,
)

DESCRIPTOR.message_types_by_name["Empty"] = _EMPTY
DESCRIPTOR.message_types_by_name["PingRequest"] = _PINGREQUEST
DESCRIPTOR.message_types_by_name["PingReply"] = _PINGREPLY
DESCRIPTOR.message_types_by_name["StreamingPingRequest"] = _STREAMINGPINGREQUEST
DESCRIPTOR.message_types_by_name["StreamingPingEvent"] = _STREAMINGPINGEVENT
DESCRIPTOR.message_types_by_name["GetServerIdReply"] = _GETSERVERIDREPLY
DESCRIPTOR.message_types_by_name["ExecutionPlanSnapshotRequest"] = _EXECUTIONPLANSNAPSHOTREQUEST
DESCRIPTOR.message_types_by_name["ExecutionPlanSnapshotReply"] = _EXECUTIONPLANSNAPSHOTREPLY
DESCRIPTOR.message_types_by_name["ExternalPartitionNamesRequest"] = _EXTERNALPARTITIONNAMESREQUEST
DESCRIPTOR.message_types_by_name["ExternalPartitionNamesReply"] = _EXTERNALPARTITIONNAMESREPLY
DESCRIPTOR.message_types_by_name["ExternalPartitionConfigRequest"] = _EXTERNALPARTITIONCONFIGREQUEST
DESCRIPTOR.message_types_by_name["ExternalPartitionConfigReply"] = _EXTERNALPARTITIONCONFIGREPLY
DESCRIPTOR.message_types_by_name["ExternalPartitionTagsRequest"] = _EXTERNALPARTITIONTAGSREQUEST
DESCRIPTOR.message_types_by_name["ExternalPartitionTagsReply"] = _EXTERNALPARTITIONTAGSREPLY
DESCRIPTOR.message_types_by_name[
    "ExternalPartitionSetExecutionParamsRequest"
] = _EXTERNALPARTITIONSETEXECUTIONPARAMSREQUEST
DESCRIPTOR.message_types_by_name[
    "ExternalPartitionSetExecutionParamsReply"
] = _EXTERNALPARTITIONSETEXECUTIONPARAMSREPLY
DESCRIPTOR.message_types_by_name["ListRepositoriesRequest"] = _LISTREPOSITORIESREQUEST
DESCRIPTOR.message_types_by_name["ListRepositoriesReply"] = _LISTREPOSITORIESREPLY
DESCRIPTOR.message_types_by_name[
    "ExternalPipelineSubsetSnapshotRequest"
] = _EXTERNALPIPELINESUBSETSNAPSHOTREQUEST
DESCRIPTOR.message_types_by_name[
    "ExternalPipelineSubsetSnapshotReply"
] = _EXTERNALPIPELINESUBSETSNAPSHOTREPLY
DESCRIPTOR.message_types_by_name["ExternalRepositoryRequest"] = _EXTERNALREPOSITORYREQUEST
DESCRIPTOR.message_types_by_name["ExternalRepositoryReply"] = _EXTERNALREPOSITORYREPLY
DESCRIPTOR.message_types_by_name[
    "StreamingExternalRepositoryEvent"
] = _STREAMINGEXTERNALREPOSITORYEVENT
DESCRIPTOR.message_types_by_name[
    "ExternalScheduleExecutionRequest"
] = _EXTERNALSCHEDULEEXECUTIONREQUEST
DESCRIPTOR.message_types_by_name["ExternalScheduleExecutionReply"] = _EXTERNALSCHEDULEEXECUTIONREPLY
DESCRIPTOR.message_types_by_name["ExternalSensorExecutionRequest"] = _EXTERNALSENSOREXECUTIONREQUEST
DESCRIPTOR.message_types_by_name["ExternalSensorExecutionReply"] = _EXTERNALSENSOREXECUTIONREPLY
DESCRIPTOR.message_types_by_name["ShutdownServerReply"] = _SHUTDOWNSERVERREPLY
DESCRIPTOR.message_types_by_name["CancelExecutionRequest"] = _CANCELEXECUTIONREQUEST
DESCRIPTOR.message_types_by_name["CancelExecutionReply"] = _CANCELEXECUTIONREPLY
DESCRIPTOR.message_types_by_name["CanCancelExecutionRequest"] = _CANCANCELEXECUTIONREQUEST
DESCRIPTOR.message_types_by_name["CanCancelExecutionReply"] = _CANCANCELEXECUTIONREPLY
DESCRIPTOR.message_types_by_name["StartRunRequest"] = _STARTRUNREQUEST
DESCRIPTOR.message_types_by_name["StartRunReply"] = _STARTRUNREPLY
DESCRIPTOR.message_types_by_name["GetCurrentImageReply"] = _GETCURRENTIMAGEREPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Empty = _reflection.GeneratedProtocolMessageType(
    "Empty",
    (_message.Message,),
    {
        "DESCRIPTOR": _EMPTY,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.Empty)
    },
)
_sym_db.RegisterMessage(Empty)

PingRequest = _reflection.GeneratedProtocolMessageType(
    "PingRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _PINGREQUEST,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.PingRequest)
    },
)
_sym_db.RegisterMessage(PingRequest)

PingReply = _reflection.GeneratedProtocolMessageType(
    "PingReply",
    (_message.Message,),
    {
        "DESCRIPTOR": _PINGREPLY,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.PingReply)
    },
)
_sym_db.RegisterMessage(PingReply)

StreamingPingRequest = _reflection.GeneratedProtocolMessageType(
    "StreamingPingRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _STREAMINGPINGREQUEST,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.StreamingPingRequest)
    },
)
_sym_db.RegisterMessage(StreamingPingRequest)

StreamingPingEvent = _reflection.GeneratedProtocolMessageType(
    "StreamingPingEvent",
    (_message.Message,),
    {
        "DESCRIPTOR": _STREAMINGPINGEVENT,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.StreamingPingEvent)
    },
)
_sym_db.RegisterMessage(StreamingPingEvent)

GetServerIdReply = _reflection.GeneratedProtocolMessageType(
    "GetServerIdReply",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETSERVERIDREPLY,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.GetServerIdReply)
    },
)
_sym_db.RegisterMessage(GetServerIdReply)

ExecutionPlanSnapshotRequest = _reflection.GeneratedProtocolMessageType(
    "ExecutionPlanSnapshotRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXECUTIONPLANSNAPSHOTREQUEST,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.ExecutionPlanSnapshotRequest)
    },
)
_sym_db.RegisterMessage(ExecutionPlanSnapshotRequest)

ExecutionPlanSnapshotReply = _reflection.GeneratedProtocolMessageType(
    "ExecutionPlanSnapshotReply",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXECUTIONPLANSNAPSHOTREPLY,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.ExecutionPlanSnapshotReply)
    },
)
_sym_db.RegisterMessage(ExecutionPlanSnapshotReply)

ExternalPartitionNamesRequest = _reflection.GeneratedProtocolMessageType(
    "ExternalPartitionNamesRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXTERNALPARTITIONNAMESREQUEST,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.ExternalPartitionNamesRequest)
    },
)
_sym_db.RegisterMessage(ExternalPartitionNamesRequest)

ExternalPartitionNamesReply = _reflection.GeneratedProtocolMessageType(
    "ExternalPartitionNamesReply",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXTERNALPARTITIONNAMESREPLY,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.ExternalPartitionNamesReply)
    },
)
_sym_db.RegisterMessage(ExternalPartitionNamesReply)

ExternalPartitionConfigRequest = _reflection.GeneratedProtocolMessageType(
    "ExternalPartitionConfigRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXTERNALPARTITIONCONFIGREQUEST,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.ExternalPartitionConfigRequest)
    },
)
_sym_db.RegisterMessage(ExternalPartitionConfigRequest)

ExternalPartitionConfigReply = _reflection.GeneratedProtocolMessageType(
    "ExternalPartitionConfigReply",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXTERNALPARTITIONCONFIGREPLY,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.ExternalPartitionConfigReply)
    },
)
_sym_db.RegisterMessage(ExternalPartitionConfigReply)

ExternalPartitionTagsRequest = _reflection.GeneratedProtocolMessageType(
    "ExternalPartitionTagsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXTERNALPARTITIONTAGSREQUEST,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.ExternalPartitionTagsRequest)
    },
)
_sym_db.RegisterMessage(ExternalPartitionTagsRequest)

ExternalPartitionTagsReply = _reflection.GeneratedProtocolMessageType(
    "ExternalPartitionTagsReply",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXTERNALPARTITIONTAGSREPLY,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.ExternalPartitionTagsReply)
    },
)
_sym_db.RegisterMessage(ExternalPartitionTagsReply)

ExternalPartitionSetExecutionParamsRequest = _reflection.GeneratedProtocolMessageType(
    "ExternalPartitionSetExecutionParamsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXTERNALPARTITIONSETEXECUTIONPARAMSREQUEST,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.ExternalPartitionSetExecutionParamsRequest)
    },
)
_sym_db.RegisterMessage(ExternalPartitionSetExecutionParamsRequest)

ExternalPartitionSetExecutionParamsReply = _reflection.GeneratedProtocolMessageType(
    "ExternalPartitionSetExecutionParamsReply",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXTERNALPARTITIONSETEXECUTIONPARAMSREPLY,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.ExternalPartitionSetExecutionParamsReply)
    },
)
_sym_db.RegisterMessage(ExternalPartitionSetExecutionParamsReply)

ListRepositoriesRequest = _reflection.GeneratedProtocolMessageType(
    "ListRepositoriesRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTREPOSITORIESREQUEST,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.ListRepositoriesRequest)
    },
)
_sym_db.RegisterMessage(ListRepositoriesRequest)

ListRepositoriesReply = _reflection.GeneratedProtocolMessageType(
    "ListRepositoriesReply",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTREPOSITORIESREPLY,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.ListRepositoriesReply)
    },
)
_sym_db.RegisterMessage(ListRepositoriesReply)

ExternalPipelineSubsetSnapshotRequest = _reflection.GeneratedProtocolMessageType(
    "ExternalPipelineSubsetSnapshotRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXTERNALPIPELINESUBSETSNAPSHOTREQUEST,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.ExternalPipelineSubsetSnapshotRequest)
    },
)
_sym_db.RegisterMessage(ExternalPipelineSubsetSnapshotRequest)

ExternalPipelineSubsetSnapshotReply = _reflection.GeneratedProtocolMessageType(
    "ExternalPipelineSubsetSnapshotReply",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXTERNALPIPELINESUBSETSNAPSHOTREPLY,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.ExternalPipelineSubsetSnapshotReply)
    },
)
_sym_db.RegisterMessage(ExternalPipelineSubsetSnapshotReply)

ExternalRepositoryRequest = _reflection.GeneratedProtocolMessageType(
    "ExternalRepositoryRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXTERNALREPOSITORYREQUEST,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.ExternalRepositoryRequest)
    },
)
_sym_db.RegisterMessage(ExternalRepositoryRequest)

ExternalRepositoryReply = _reflection.GeneratedProtocolMessageType(
    "ExternalRepositoryReply",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXTERNALREPOSITORYREPLY,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.ExternalRepositoryReply)
    },
)
_sym_db.RegisterMessage(ExternalRepositoryReply)

StreamingExternalRepositoryEvent = _reflection.GeneratedProtocolMessageType(
    "StreamingExternalRepositoryEvent",
    (_message.Message,),
    {
        "DESCRIPTOR": _STREAMINGEXTERNALREPOSITORYEVENT,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.StreamingExternalRepositoryEvent)
    },
)
_sym_db.RegisterMessage(StreamingExternalRepositoryEvent)

ExternalScheduleExecutionRequest = _reflection.GeneratedProtocolMessageType(
    "ExternalScheduleExecutionRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXTERNALSCHEDULEEXECUTIONREQUEST,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.ExternalScheduleExecutionRequest)
    },
)
_sym_db.RegisterMessage(ExternalScheduleExecutionRequest)

ExternalScheduleExecutionReply = _reflection.GeneratedProtocolMessageType(
    "ExternalScheduleExecutionReply",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXTERNALSCHEDULEEXECUTIONREPLY,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.ExternalScheduleExecutionReply)
    },
)
_sym_db.RegisterMessage(ExternalScheduleExecutionReply)

ExternalSensorExecutionRequest = _reflection.GeneratedProtocolMessageType(
    "ExternalSensorExecutionRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXTERNALSENSOREXECUTIONREQUEST,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.ExternalSensorExecutionRequest)
    },
)
_sym_db.RegisterMessage(ExternalSensorExecutionRequest)

ExternalSensorExecutionReply = _reflection.GeneratedProtocolMessageType(
    "ExternalSensorExecutionReply",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXTERNALSENSOREXECUTIONREPLY,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.ExternalSensorExecutionReply)
    },
)
_sym_db.RegisterMessage(ExternalSensorExecutionReply)

ShutdownServerReply = _reflection.GeneratedProtocolMessageType(
    "ShutdownServerReply",
    (_message.Message,),
    {
        "DESCRIPTOR": _SHUTDOWNSERVERREPLY,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.ShutdownServerReply)
    },
)
_sym_db.RegisterMessage(ShutdownServerReply)

CancelExecutionRequest = _reflection.GeneratedProtocolMessageType(
    "CancelExecutionRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CANCELEXECUTIONREQUEST,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.CancelExecutionRequest)
    },
)
_sym_db.RegisterMessage(CancelExecutionRequest)

CancelExecutionReply = _reflection.GeneratedProtocolMessageType(
    "CancelExecutionReply",
    (_message.Message,),
    {
        "DESCRIPTOR": _CANCELEXECUTIONREPLY,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.CancelExecutionReply)
    },
)
_sym_db.RegisterMessage(CancelExecutionReply)

CanCancelExecutionRequest = _reflection.GeneratedProtocolMessageType(
    "CanCancelExecutionRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CANCANCELEXECUTIONREQUEST,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.CanCancelExecutionRequest)
    },
)
_sym_db.RegisterMessage(CanCancelExecutionRequest)

CanCancelExecutionReply = _reflection.GeneratedProtocolMessageType(
    "CanCancelExecutionReply",
    (_message.Message,),
    {
        "DESCRIPTOR": _CANCANCELEXECUTIONREPLY,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.CanCancelExecutionReply)
    },
)
_sym_db.RegisterMessage(CanCancelExecutionReply)

StartRunRequest = _reflection.GeneratedProtocolMessageType(
    "StartRunRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _STARTRUNREQUEST,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.StartRunRequest)
    },
)
_sym_db.RegisterMessage(StartRunRequest)

StartRunReply = _reflection.GeneratedProtocolMessageType(
    "StartRunReply",
    (_message.Message,),
    {
        "DESCRIPTOR": _STARTRUNREPLY,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.StartRunReply)
    },
)
_sym_db.RegisterMessage(StartRunReply)

GetCurrentImageReply = _reflection.GeneratedProtocolMessageType(
    "GetCurrentImageReply",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETCURRENTIMAGEREPLY,
        "__module__": "api_pb2"
        # @@protoc_insertion_point(class_scope:api.GetCurrentImageReply)
    },
)
_sym_db.RegisterMessage(GetCurrentImageReply)


_DAGSTERAPI = _descriptor.ServiceDescriptor(
    name="DagsterApi",
    full_name="api.DagsterApi",
    file=DESCRIPTOR,
    index=0,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
    serialized_start=2687,
    serialized_end=4383,
    methods=[
        _descriptor.MethodDescriptor(
            name="Ping",
            full_name="api.DagsterApi.Ping",
            index=0,
            containing_service=None,
            input_type=_PINGREQUEST,
            output_type=_PINGREPLY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="Heartbeat",
            full_name="api.DagsterApi.Heartbeat",
            index=1,
            containing_service=None,
            input_type=_PINGREQUEST,
            output_type=_PINGREPLY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="StreamingPing",
            full_name="api.DagsterApi.StreamingPing",
            index=2,
            containing_service=None,
            input_type=_STREAMINGPINGREQUEST,
            output_type=_STREAMINGPINGEVENT,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="GetServerId",
            full_name="api.DagsterApi.GetServerId",
            index=3,
            containing_service=None,
            input_type=_EMPTY,
            output_type=_GETSERVERIDREPLY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ExecutionPlanSnapshot",
            full_name="api.DagsterApi.ExecutionPlanSnapshot",
            index=4,
            containing_service=None,
            input_type=_EXECUTIONPLANSNAPSHOTREQUEST,
            output_type=_EXECUTIONPLANSNAPSHOTREPLY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListRepositories",
            full_name="api.DagsterApi.ListRepositories",
            index=5,
            containing_service=None,
            input_type=_LISTREPOSITORIESREQUEST,
            output_type=_LISTREPOSITORIESREPLY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ExternalPartitionNames",
            full_name="api.DagsterApi.ExternalPartitionNames",
            index=6,
            containing_service=None,
            input_type=_EXTERNALPARTITIONNAMESREQUEST,
            output_type=_EXTERNALPARTITIONNAMESREPLY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ExternalPartitionConfig",
            full_name="api.DagsterApi.ExternalPartitionConfig",
            index=7,
            containing_service=None,
            input_type=_EXTERNALPARTITIONCONFIGREQUEST,
            output_type=_EXTERNALPARTITIONCONFIGREPLY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ExternalPartitionTags",
            full_name="api.DagsterApi.ExternalPartitionTags",
            index=8,
            containing_service=None,
            input_type=_EXTERNALPARTITIONTAGSREQUEST,
            output_type=_EXTERNALPARTITIONTAGSREPLY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ExternalPartitionSetExecutionParams",
            full_name="api.DagsterApi.ExternalPartitionSetExecutionParams",
            index=9,
            containing_service=None,
            input_type=_EXTERNALPARTITIONSETEXECUTIONPARAMSREQUEST,
            output_type=_EXTERNALPARTITIONSETEXECUTIONPARAMSREPLY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ExternalPipelineSubsetSnapshot",
            full_name="api.DagsterApi.ExternalPipelineSubsetSnapshot",
            index=10,
            containing_service=None,
            input_type=_EXTERNALPIPELINESUBSETSNAPSHOTREQUEST,
            output_type=_EXTERNALPIPELINESUBSETSNAPSHOTREPLY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ExternalRepository",
            full_name="api.DagsterApi.ExternalRepository",
            index=11,
            containing_service=None,
            input_type=_EXTERNALREPOSITORYREQUEST,
            output_type=_EXTERNALREPOSITORYREPLY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="StreamingExternalRepository",
            full_name="api.DagsterApi.StreamingExternalRepository",
            index=12,
            containing_service=None,
            input_type=_EXTERNALREPOSITORYREQUEST,
            output_type=_STREAMINGEXTERNALREPOSITORYEVENT,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ExternalScheduleExecution",
            full_name="api.DagsterApi.ExternalScheduleExecution",
            index=13,
            containing_service=None,
            input_type=_EXTERNALSCHEDULEEXECUTIONREQUEST,
            output_type=_EXTERNALSCHEDULEEXECUTIONREPLY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ExternalSensorExecution",
            full_name="api.DagsterApi.ExternalSensorExecution",
            index=14,
            containing_service=None,
            input_type=_EXTERNALSENSOREXECUTIONREQUEST,
            output_type=_EXTERNALSENSOREXECUTIONREPLY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ShutdownServer",
            full_name="api.DagsterApi.ShutdownServer",
            index=15,
            containing_service=None,
            input_type=_EMPTY,
            output_type=_SHUTDOWNSERVERREPLY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="CancelExecution",
            full_name="api.DagsterApi.CancelExecution",
            index=16,
            containing_service=None,
            input_type=_CANCELEXECUTIONREQUEST,
            output_type=_CANCELEXECUTIONREPLY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="CanCancelExecution",
            full_name="api.DagsterApi.CanCancelExecution",
            index=17,
            containing_service=None,
            input_type=_CANCANCELEXECUTIONREQUEST,
            output_type=_CANCANCELEXECUTIONREPLY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="StartRun",
            full_name="api.DagsterApi.StartRun",
            index=18,
            containing_service=None,
            input_type=_STARTRUNREQUEST,
            output_type=_STARTRUNREPLY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="GetCurrentImage",
            full_name="api.DagsterApi.GetCurrentImage",
            index=19,
            containing_service=None,
            input_type=_EMPTY,
            output_type=_GETCURRENTIMAGEREPLY,
            serialized_options=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_DAGSTERAPI)

DESCRIPTOR.services_by_name["DagsterApi"] = _DAGSTERAPI

# @@protoc_insertion_point(module_scope)



import logging
import sys
from abc import abstractclassmethod, abstractmethod
from contextlib import AbstractContextManager

import pendulum
from dagster import DagsterInstance, check
from dagster.core.definitions.sensor import DEFAULT_SENSOR_DAEMON_INTERVAL
from dagster.daemon.backfill import execute_backfill_iteration
from dagster.daemon.sensor import execute_sensor_iteration_loop
from dagster.daemon.types import DaemonHeartbeat
from dagster.scheduler import execute_scheduler_iteration
from dagster.utils.error import SerializableErrorInfo, serializable_error_info_from_exc_info
from dagster.utils.log import default_format_string

# Interval at which heartbeats are posted
DAEMON_HEARTBEAT_INTERVAL_SECONDS = 30


def _mockable_localtime(_):
    now_time = pendulum.now()
    return now_time.timetuple()


def get_default_daemon_logger(daemon_name):
    handler = logging.StreamHandler(sys.stdout)
    logger = logging.getLogger(daemon_name)
    logger.setLevel(logging.INFO)
    logger.handlers = [handler]

    formatter = logging.Formatter(default_format_string(), "%Y-%m-%d %H:%M:%S")

    formatter.converter = _mockable_localtime

    handler.setFormatter(formatter)
    return logger


class CompletedIteration(object):
    pass


class DagsterDaemon(AbstractContextManager):
    def __init__(self, interval_seconds):
        self._logger = get_default_daemon_logger(type(self).__name__)
        self.interval_seconds = check.numeric_param(interval_seconds, "interval_seconds")

        self._last_iteration_time = None
        self._last_heartbeat_time = None
        self._current_iteration_exceptions = None
        self._last_iteration_exceptions = None

        self._first_error_logged = False

    @abstractclassmethod
    def daemon_type(cls):
        """
        returns: str
        """

    def __exit__(self, _exception_type, _exception_value, _traceback):
        pass

    def run_loop(self, daemon_uuid, daemon_shutdown_event, grpc_server_registry, until=None):
        # Each loop runs in its own thread with its own instance
        with DagsterInstance.get() as instance:
            while not daemon_shutdown_event.is_set() and (not until or pendulum.now("UTC") < until):
                curr_time = pendulum.now("UTC")
                if (
                    not self._last_iteration_time
                    or (curr_time - self._last_iteration_time).total_seconds()
                    >= self.interval_seconds
                ):
                    self._last_iteration_time = curr_time
                    self._run_iteration(
                        instance, daemon_uuid, daemon_shutdown_event, grpc_server_registry, until
                    )

                daemon_shutdown_event.wait(0.5)

    def _run_iteration(
        self, instance, daemon_uuid, daemon_shutdown_event, grpc_server_registry, until=None
    ):
        # Build a list of any exceptions encountered during the iteration.
        # Once the iteration completes, this is copied to last_iteration_exceptions
        # which is used in the heartbeats. This guarantees that heartbeats contain the full
        # list of errors raised.
        self._current_iteration_exceptions = []
        daemon_generator = self.run_iteration(instance, daemon_shutdown_event, grpc_server_registry)

        while (not daemon_shutdown_event.is_set()) and (not until or pendulum.now("UTC") < until):
            try:
                result = check.opt_inst(
                    next(daemon_generator), tuple([SerializableErrorInfo, CompletedIteration])
                )
                if isinstance(result, CompletedIteration):
                    self._last_iteration_exceptions = self._current_iteration_exceptions
                    self._current_iteration_exceptions = []
                elif result:
                    self._current_iteration_exceptions.append(result)
            except StopIteration:
                self._last_iteration_exceptions = self._current_iteration_exceptions
                break
            except Exception:  # pylint: disable=broad-except
                error_info = serializable_error_info_from_exc_info(sys.exc_info())
                self._logger.error("Caught error:\n{}".format(error_info))
                self._current_iteration_exceptions.append(error_info)
                self._last_iteration_exceptions = self._current_iteration_exceptions
                break
            finally:
                self._check_add_heartbeat(instance, daemon_uuid)

    def _check_add_heartbeat(self, instance, daemon_uuid):
        # Always log a heartbeat after the first time an iteration returns an error to make sure we
        # don't incorrectly say the daemon is healthy
        first_time_logging_error = self._last_iteration_exceptions and not self._first_error_logged

        curr_time = pendulum.now("UTC")
        if not first_time_logging_error and (
            self._last_heartbeat_time
            and (curr_time - self._last_heartbeat_time).total_seconds()
            < DAEMON_HEARTBEAT_INTERVAL_SECONDS
        ):
            return

        if first_time_logging_error:
            self._first_error_logged = True

        daemon_type = self.daemon_type()

        last_stored_heartbeat = instance.get_daemon_heartbeats().get(daemon_type)
        if (
            self._last_heartbeat_time  # not the first heartbeat
            and last_stored_heartbeat
            and last_stored_heartbeat.daemon_id != daemon_uuid
        ):
            self._logger.warning(
                "Taking over from another {} daemon process. If this "
                "message reoccurs, you may have multiple daemons running which is not supported. "
                "Last heartbeat daemon id: {}, "
                "Current daemon_id: {}".format(
                    daemon_type,
                    last_stored_heartbeat.daemon_id,
                    daemon_uuid,
                )
            )

        self._last_heartbeat_time = curr_time

        instance.add_daemon_heartbeat(
            DaemonHeartbeat(
                curr_time.float_timestamp,
                daemon_type,
                daemon_uuid,
                errors=self._last_iteration_exceptions,
            )
        )

    @abstractmethod
    def run_iteration(self, instance, daemon_shutdown_event, grpc_server_registry):
        """
        Execute the daemon. In order to avoid blocking the controller thread for extended periods,
        daemons can yield control during this method. Yields can be either NoneType or a
        SerializableErrorInfo

        returns: generator (SerializableErrorInfo).
        """


class SchedulerDaemon(DagsterDaemon):
    def __init__(
        self,
        interval_seconds,
        max_catchup_runs,
    ):
        super(SchedulerDaemon, self).__init__(interval_seconds)
        self._max_catchup_runs = max_catchup_runs

    @staticmethod
    def create_from_instance(instance):
        max_catchup_runs = instance.scheduler.max_catchup_runs

        from dagster.daemon.controller import DEFAULT_DAEMON_INTERVAL_SECONDS

        return SchedulerDaemon(
            interval_seconds=DEFAULT_DAEMON_INTERVAL_SECONDS,
            max_catchup_runs=max_catchup_runs,
        )

    @classmethod
    def daemon_type(cls):
        return "SCHEDULER"

    def run_iteration(self, instance, daemon_shutdown_event, grpc_server_registry):
        yield from execute_scheduler_iteration(
            instance, grpc_server_registry, self._logger, self._max_catchup_runs
        )


class SensorDaemon(DagsterDaemon):
    @staticmethod
    def create_from_instance(_instance):
        return SensorDaemon(interval_seconds=DEFAULT_SENSOR_DAEMON_INTERVAL)

    @classmethod
    def daemon_type(cls):
        return "SENSOR"

    def run_iteration(self, instance, daemon_shutdown_event, grpc_server_registry):
        yield from execute_sensor_iteration_loop(
            instance, grpc_server_registry, self._logger, daemon_shutdown_event
        )


class BackfillDaemon(DagsterDaemon):
    @staticmethod
    def create_from_instance(_instance):
        from dagster.daemon.controller import DEFAULT_DAEMON_INTERVAL_SECONDS

        return BackfillDaemon(interval_seconds=DEFAULT_DAEMON_INTERVAL_SECONDS)

    @classmethod
    def daemon_type(cls):
        return "BACKFILL"

    def run_iteration(self, instance, daemon_shutdown_event, grpc_server_registry):
        yield from execute_backfill_iteration(instance, grpc_server_registry, self._logger)



from collections import namedtuple

from dagster import check


class EvaluationStack(namedtuple("_EvaluationStack", "entries")):
    def __new__(cls, entries):
        return super(EvaluationStack, cls).__new__(
            cls,
            check.list_param(entries, "entries", of_type=EvaluationStackEntry),
        )

    @property
    def levels(self):
        return [
            entry.field_name
            for entry in self.entries
            if isinstance(entry, EvaluationStackPathEntry)
        ]

    def for_field(self, field_name):
        return EvaluationStack(entries=self.entries + [EvaluationStackPathEntry(field_name)])

    def for_array_index(self, list_index):
        return EvaluationStack(entries=self.entries + [EvaluationStackListItemEntry(list_index)])


class EvaluationStackEntry:  # marker interface
    pass


class EvaluationStackPathEntry(
    namedtuple("_EvaluationStackEntry", "field_name"), EvaluationStackEntry
):
    def __new__(cls, field_name):
        return super(EvaluationStackPathEntry, cls).__new__(
            cls,
            check.str_param(field_name, "field_name"),
        )


class EvaluationStackListItemEntry(
    namedtuple("_EvaluationStackListItemEntry", "list_index"), EvaluationStackEntry
):
    def __new__(cls, list_index):
        check.int_param(list_index, "list_index")
        check.param_invariant(list_index >= 0, "list_index")
        return super(EvaluationStackListItemEntry, cls).__new__(cls, list_index)


def get_friendly_path_msg(stack):
    return get_friendly_path_info(stack)[0]


def get_friendly_path_info(stack):
    if not stack.entries:
        path = ""
        path_msg = "at the root"
    else:
        comps = ["root"]
        for entry in stack.entries:
            if isinstance(entry, EvaluationStackPathEntry):
                comp = ":" + entry.field_name
                comps.append(comp)
            elif isinstance(entry, EvaluationStackListItemEntry):
                comps.append("[{i}]".format(i=entry.list_index))
            else:
                check.failed("unsupported")

        path = "".join(comps)
        path_msg = "at path " + path
    return path_msg, path



import os
import time

from dagster import check
from dagster.core.errors import DagsterBackfillFailedError
from dagster.core.execution.backfill import (
    BulkActionStatus,
    PartitionBackfill,
    submit_backfill_runs,
)
from dagster.core.host_representation.handle_manager import RepositoryLocationHandleManager
from dagster.core.instance import DagsterInstance
from dagster.core.storage.pipeline_run import PipelineRun, PipelineRunsFilter
from dagster.core.storage.tags import PARTITION_NAME_TAG

# out of abundance of caution, sleep at checkpoints in case we are pinning CPU by submitting lots
# of jobs all at once
CHECKPOINT_INTERVAL = 1
CHECKPOINT_COUNT = 25


def _check_for_debug_crash(debug_crash_flags, key):
    if not debug_crash_flags:
        return

    kill_signal = debug_crash_flags.get(key)
    if not kill_signal:
        return

    os.kill(os.getpid(), kill_signal)
    time.sleep(10)
    raise Exception("Process didn't terminate after sending crash signal")


def execute_backfill_iteration(instance, grpc_server_registry, logger, debug_crash_flags=None):
    check.inst_param(instance, "instance", DagsterInstance)

    backfill_jobs = instance.get_backfills(status=BulkActionStatus.REQUESTED)

    if not backfill_jobs:
        logger.info("No backfill jobs requested.")
        yield
        return

    with RepositoryLocationHandleManager(grpc_server_registry) as handle_manager:

        for backfill_job in backfill_jobs:
            backfill_id = backfill_job.backfill_id

            if not backfill_job.last_submitted_partition_name:
                logger.info(f"Starting backfill for {backfill_id}")
            else:
                logger.info(
                    f"Resuming backfill for {backfill_id} from {backfill_job.last_submitted_partition_name}"
                )

            origin = (
                backfill_job.partition_set_origin.external_repository_origin.repository_location_origin
            )

            try:
                repo_location_handle = handle_manager.get_handle(origin)
                repo_location = repo_location_handle.create_location()
                has_more = True
                while has_more:
                    # refetch the backfill job
                    backfill_job = instance.get_backfill(backfill_job.backfill_id)
                    if backfill_job.status != BulkActionStatus.REQUESTED:
                        break

                    chunk, checkpoint, has_more = _get_partitions_chunk(
                        instance, logger, backfill_job, CHECKPOINT_COUNT
                    )
                    _check_for_debug_crash(debug_crash_flags, "BEFORE_SUBMIT")

                    if chunk:

                        for _run_id in submit_backfill_runs(
                            instance, repo_location, backfill_job, chunk
                        ):
                            yield

                    _check_for_debug_crash(debug_crash_flags, "AFTER_SUBMIT")

                    if has_more:
                        instance.update_backfill(backfill_job.with_partition_checkpoint(checkpoint))
                        yield
                        time.sleep(CHECKPOINT_INTERVAL)
                    else:
                        logger.info(
                            f"Backfill completed for {backfill_id} for {len(backfill_job.partition_names)} partitions"
                        )
                        instance.update_backfill(
                            backfill_job.with_status(BulkActionStatus.COMPLETED)
                        )
                        yield
            except DagsterBackfillFailedError as e:
                error_info = e.serializable_error_info
                instance.update_backfill(
                    backfill_job.with_status(BulkActionStatus.FAILED).with_error(error_info)
                )
                if error_info:
                    logger.error(f"Backfill failed for {backfill_id}: {error_info.to_string()}")
                    yield error_info


def _get_partitions_chunk(instance, logger, backfill_job, chunk_size):
    check.inst_param(backfill_job, "backfill_job", PartitionBackfill)
    partition_names = backfill_job.partition_names
    checkpoint = backfill_job.last_submitted_partition_name

    if (
        backfill_job.last_submitted_partition_name
        and backfill_job.last_submitted_partition_name in partition_names
    ):
        index = partition_names.index(backfill_job.last_submitted_partition_name)
        partition_names = partition_names[index + 1 :]

    # for idempotence, fetch all runs with the current backfill id
    backfill_runs = instance.get_runs(
        PipelineRunsFilter(tags=PipelineRun.tags_for_backfill_id(backfill_job.backfill_id))
    )
    completed_partitions = set([run.tags.get(PARTITION_NAME_TAG) for run in backfill_runs])
    initial_checkpoint = (
        partition_names.index(checkpoint) + 1 if checkpoint and checkpoint in partition_names else 0
    )
    partition_names = partition_names[initial_checkpoint:]
    has_more = chunk_size < len(partition_names)
    partitions_chunk = partition_names[:chunk_size]
    next_checkpoint = partitions_chunk[-1]

    to_skip = set(partitions_chunk).intersection(completed_partitions)
    if to_skip:
        logger.info(
            f"Found {len(to_skip)} existing runs for backfill {backfill_job.backfill_id}, skipping"
        )
    to_submit = [
        partition_name
        for partition_name in partitions_chunk
        if partition_name not in completed_partitions
    ]
    return to_submit, next_checkpoint, has_more



import sqlalchemy as db
from dagster import AssetKey
from dagster.core.events.log import EventRecord
from dagster.serdes import deserialize_json_to_dagster_namedtuple
from tqdm import tqdm

SECONDARY_INDEX_ASSET_KEY = "asset_key_table"

REINDEX_DATA_MIGRATIONS = {
    SECONDARY_INDEX_ASSET_KEY: lambda: migrate_asset_key_data,
}


def migrate_event_log_data(instance=None):
    """
    Utility method to migrate the data in the existing event log records.  Reads every event log row
    reachable from the instance and reserializes it to event log storage.  Deserializing and then
    reserializing the event from storage allows for things like SQL column extraction, filling
    explicit default values, etc.
    """
    from dagster.core.storage.event_log.sql_event_log import SqlEventLogStorage

    event_log_storage = instance._event_storage  # pylint: disable=protected-access

    if not isinstance(event_log_storage, SqlEventLogStorage):
        return

    for run in instance.get_runs():
        event_records_by_id = event_log_storage.get_logs_for_run_by_log_id(run.run_id)
        for record_id, event in event_records_by_id.items():
            event_log_storage.update_event_log_record(record_id, event)


def migrate_asset_key_data(event_log_storage, print_fn=None):
    """
    Utility method to build an asset key index from the data in existing event log records.
    Takes in event_log_storage, and a print_fn to keep track of progress.
    """
    from dagster.core.storage.event_log.sql_event_log import SqlEventLogStorage
    from .schema import AssetKeyTable, SqlEventLogStorageTable

    if not isinstance(event_log_storage, SqlEventLogStorage):
        return

    query = (
        db.select([SqlEventLogStorageTable.c.asset_key])
        .where(SqlEventLogStorageTable.c.asset_key != None)
        .group_by(SqlEventLogStorageTable.c.asset_key)
    )
    with event_log_storage.index_connection() as conn:
        if print_fn:
            print_fn("Querying event logs.")
        to_insert = conn.execute(query).fetchall()
        if print_fn:
            print_fn("Found {} records to index".format(len(to_insert)))
            to_insert = tqdm(to_insert)

        for (asset_key,) in to_insert:
            try:
                conn.execute(
                    AssetKeyTable.insert().values(  # pylint: disable=no-value-for-parameter
                        asset_key=AssetKey.from_db_string(asset_key).to_string()
                    )
                )
            except db.exc.IntegrityError:
                # asset key already present
                pass


def sql_asset_event_generator(conn, cursor=None, batch_size=1000):
    from .schema import SqlEventLogStorageTable

    while True:
        query = db.select([SqlEventLogStorageTable.c.id, SqlEventLogStorageTable.c.event]).where(
            SqlEventLogStorageTable.c.asset_key != None
        )
        if cursor:
            query = query.where(SqlEventLogStorageTable.c.id < cursor)
        query = query.order_by(SqlEventLogStorageTable.c.id.desc()).limit(batch_size)
        fetched = conn.execute(query).fetchall()

        for (record_id, event_json) in fetched:
            cursor = record_id
            event_record = deserialize_json_to_dagster_namedtuple(event_json)
            if not isinstance(event_record, EventRecord):
                continue
            yield (record_id, event_record)

        if fetched < batch_size:
            break



from dagster import check
from dagster.serdes import deserialize_json_to_dagster_namedtuple


def sync_get_streaming_external_repositories_data_grpc(api_client, repository_location_handle):
    from dagster.core.host_representation import (
        RepositoryLocationHandle,
        ExternalRepositoryOrigin,
    )

    check.inst_param(
        repository_location_handle, "repository_location_handle", RepositoryLocationHandle
    )

    repo_datas = {}
    for repository_name in repository_location_handle.repository_names:
        external_repository_chunks = list(
            api_client.streaming_external_repository(
                external_repository_origin=ExternalRepositoryOrigin(
                    repository_location_handle.origin,
                    repository_name,
                )
            )
        )

        external_repository_data = deserialize_json_to_dagster_namedtuple(
            "".join(
                [
                    chunk["serialized_external_repository_chunk"]
                    for chunk in external_repository_chunks
                ]
            )
        )

        repo_datas[repository_name] = external_repository_data
    return repo_datas



from contextlib import contextmanager
from typing import Any, Dict, Generator, NamedTuple, Optional

from dagster import check
from dagster.config.validate import process_config
from dagster.core.definitions.environment_configs import define_resource_dictionary_cls
from dagster.core.definitions.resource import ResourceDefinition, ScopedResourcesBuilder
from dagster.core.errors import DagsterInvalidConfigError
from dagster.core.execution.context.logger import InitLoggerContext
from dagster.core.execution.resources_init import resource_initialization_manager
from dagster.core.instance import DagsterInstance
from dagster.core.log_manager import DagsterLogManager
from dagster.core.storage.io_manager import IOManager, IOManagerDefinition
from dagster.core.storage.pipeline_run import PipelineRun
from dagster.core.system_config.objects import ResourceConfig, config_map_resources
from dagster.loggers import default_system_loggers


def initialize_console_manager(pipeline_run: Optional[PipelineRun]) -> DagsterLogManager:
    # initialize default colored console logger
    loggers = []
    for logger_def, logger_config in default_system_loggers():
        loggers.append(
            logger_def.logger_fn(
                InitLoggerContext(
                    logger_config, logger_def, run_id=pipeline_run.run_id if pipeline_run else None
                )
            )
        )
    return DagsterLogManager(
        None, pipeline_run.tags if pipeline_run and pipeline_run.tags else {}, loggers
    )


def _get_mapped_resource_config(
    resource_defs: Dict[str, ResourceDefinition], run_config: Dict[str, Any]
) -> Dict[str, ResourceConfig]:
    resource_config_schema = define_resource_dictionary_cls(resource_defs)
    config_evr = process_config(resource_config_schema, run_config)
    if not config_evr.success:
        raise DagsterInvalidConfigError(
            "Error in config for resources ",
            config_evr.errors,
            run_config,
        )
    config_value = config_evr.value
    return config_map_resources(resource_defs, config_value)


@contextmanager
def build_resources(
    resources: Dict[str, Any],
    instance: DagsterInstance,
    run_config: Optional[Dict[str, Any]] = None,
    pipeline_run: Optional[PipelineRun] = None,
    log_manager: Optional[DagsterLogManager] = None,
) -> Generator[NamedTuple, None, None]:
    """Context manager that yields resources using provided resource definitions and run config.

    This API allows for using resources in an independent context. Resources will be initialized
    with the provided run config, and optionally, pipeline_run. The resulting resources will be
    yielded on a dictionary keyed identically to that provided for `resource_defs`. Upon exiting the
    context, resources will also be torn down safely.

    Args:
        resources (Dict[str, Any]): Resource instances or definitions to build. All
            required resource dependencies to a given resource must be contained within this
            dictionary, or the resource build will fail.
        instance (DagsterInstance): The dagster instance configured to instantiate resources on.
        run_config (Optional[Dict[str, Any]]): A dict representing the configuration to be provided
            to each resource during initialization and teardown.
        pipeline_run (Optional[PipelineRun]): The pipeline run to provide during resource
            initialization and teardown. If the provided resources require either the `pipeline_run`
            or `run_id` attributes of the provided context during resource initialization and/or
            teardown, this must be provided, or initialization will fail.
        log_manager (Optional[DagsterLogManager]): Log Manager to use during resource
            initialization. Defaults to system log manager.
    """
    resources = check.dict_param(resources, "resource_defs", key_type=str)
    resource_defs = {}
    # Wrap instantiated resource values in a resource definition.
    # If an instantiated IO manager is provided, wrap it in an IO manager definition.
    for resource_key, resource in resources.items():
        if isinstance(resource, ResourceDefinition):
            resource_defs[resource_key] = resource
        elif isinstance(resource, IOManager):
            resource_defs[resource_key] = IOManagerDefinition.hardcoded_io_manager(resource)
        else:
            resource_defs[resource_key] = ResourceDefinition.hardcoded_resource(resource)
    instance = check.inst_param(instance, "instance", DagsterInstance)
    run_config = check.opt_dict_param(run_config, "run_config", key_type=str)
    log_manager = check.opt_inst_param(log_manager, "log_manager", DagsterLogManager)
    mapped_resource_config = _get_mapped_resource_config(resource_defs, run_config)
    resources_manager = resource_initialization_manager(
        resource_defs=resource_defs,
        resource_configs=mapped_resource_config,
        log_manager=log_manager if log_manager else initialize_console_manager(pipeline_run),
        execution_plan=None,
        pipeline_run=pipeline_run,
        resource_keys_to_init=set(resource_defs.keys()),
        instance=instance,
        resource_instances_to_override=None,
        emit_persistent_events=False,
    )
    try:
        list(resources_manager.generate_setup_events())
        instantiated_resources = check.inst(resources_manager.get_object(), ScopedResourcesBuilder)
        yield instantiated_resources.build(
            set(instantiated_resources.resource_instance_dict.keys())
        )
    finally:
        list(resources_manager.generate_teardown_events())
